==> nextcloud-16.0.3-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/accessibility/l10n/eo.js <==
OC.L10N.register(
    "accessibility",
    {
    "High contrast theme" : "Altkontrasta etoso",
    "A high contrast theme to ease your navigation. Visual quality will be reduced but clarity will be increased." : "Altkontrasta etoso, kiu faciligas vian navigadon. Vida kvalito malpliiĝos, sed klareco pliiĝos.",
    "A dark theme to ease your eyes by reducing the overall luminosity and brightness. It is still under development, so please report any issues you may find." : "Malhela etoso, kiu helpas viajn okulojn per limigo de heleco kaj brileco. Ĝi ankoraŭ ellaboriĝas, do ne hezitu raporti problemon.",
    "Dyslexia font" : "Tiparo por limigi vortblindecon",
    "OpenDyslexic is a free typeface/font designed to mitigate some of the common reading errors caused by dyslexia." : "OpenDyslexic estas tiparo kreita por malpliigi legajn erarojn kaŭzitajn de vortblindeco (medicine „disleksio“).",
    "Accessibility" : "Alirebleco",
    "Accessibility options for nextcloud" : "Alireblecaj opcioj por Nextcloud",
    "Provides multiple accessibilities options to ease your use of Nextcloud" : "Provizas plurajn alireblecajn opciojn por faciligi vian uzon de Nextcloud.",
    "Web Content Accessibility Guidelines" : "gvidnormoj pri alirebleco de la TTT-enhavo",
    "our issue tracker" : "problem-spuradilo",
    "our design team" : "nian teamon de fasonistoj",
    "Enable" : "Ŝalti la opcion",
    "Dark theme (beta)" : "Malhela etoso (beta)",
    "OpenDyslexic is a free typeface/font designed to mitigate some of the common reading errors caused by dyslexia. The typeface was created by Abelardo Gonzalez, who released it through an open-source license." : "OpenDyslexic estas tiparo kreita por malpliigi legajn erarojn kaŭzitajn de vortblindeco (medicine „disleksio“). La tiparon kreis Abelardo Gonzalez, kiu eldonis ĝin kun malfermitkoda permesilo.",
    "Provides multiple accessibilities options to ease your use of nextcloud" : "Provizas plurajn alireblecajn opciojn por faciligi vian uzon de Nextcloud",
    "Themes" : "Etosoj",
    "Fonts" : "Tiparoj",
    "enabled" : "ebligita"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-17.0.2-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/accessibility/l10n/eo.js <==
OC.L10N.register(
    "accessibility",
    {
    "Dark theme" : "Malhela etoso",
    "A dark theme to ease your eyes by reducing the overall luminosity and brightness. It is still under development, so please report any issues you may find." : "Malhela etoso, kiu helpas viajn okulojn per limigo de heleco kaj brileco. Ĝi ankoraŭ ellaboriĝas, do ne hezitu raporti problemon.",
    "High contrast mode" : "Altkontrasta reĝimo",
    "A high contrast mode to ease your navigation. Visual quality will be reduced but clarity will be increased." : "Altkontrasta reĝimo, kiu faciligas vian navigadon. Vida kvalito malpliiĝos, sed klareco pliiĝos.",
    "Dyslexia font" : "Tiparo por limigi vortblindecon",
    "OpenDyslexic is a free typeface/font designed to mitigate some of the common reading errors caused by dyslexia." : "OpenDyslexic estas tiparo kreita por malpliigi legajn erarojn kaŭzitajn de vortblindeco (medicine „disleksio“).",
    "Accessibility" : "Alirebleco",
    "Accessibility options for nextcloud" : "Alireblecaj opcioj por Nextcloud",
    "Provides multiple accessibilities options to ease your use of Nextcloud" : "Provizas plurajn alireblecajn opciojn por faciligi vian uzon de Nextcloud.",
    "Web Content Accessibility Guidelines" : "gvidnormoj pri alirebleco de la TTT-enhavo",
    "our issue tracker" : "problem-spuradilo",
    "our design team" : "nian teamon de fasonistoj",
    "Enable" : "Ŝalti la opcion",
    "High contrast theme" : "Altkontrasta etoso",
    "A high contrast theme to ease your navigation. Visual quality will be reduced but clarity will be increased." : "Altkontrasta etoso, kiu faciligas vian navigadon. Vida kvalito malpliiĝos, sed klareco pliiĝos.",
    "Dark theme (beta)" : "Malhela etoso (beta)",
    "OpenDyslexic is a free typeface/font designed to mitigate some of the common reading errors caused by dyslexia. The typeface was created by Abelardo Gonzalez, who released it through an open-source license." : "OpenDyslexic estas tiparo kreita por malpliigi legajn erarojn kaŭzitajn de vortblindeco (medicine „disleksio“). La tiparon kreis Abelardo Gonzalez, kiu eldonis ĝin kun malfermitkoda permesilo.",
    "Provides multiple accessibilities options to ease your use of nextcloud" : "Provizas plurajn alireblecajn opciojn por faciligi vian uzon de Nextcloud",
    "Themes" : "Etosoj",
    "Fonts" : "Tiparoj",
    "enabled" : "ebligita"
},
"nplurals=2; plural=(n != 1);");
